@@ -4,10 +4,11 @@
 # 1) we don't load dependencies by storing it in __init__.py
 # 2) we can import it in setup.py for the same reason
 # 3) we can import it into your module module
-__version__ = "14.0.276"
-__versionwithtag__ = "14.0.276"
+__version__ = "14.0.287"
+__versionwithtag__ = "14.0.287"
 __majorversion__ = "14"
 __releaseversion__ = "14.0"
 __tier__ = "stable"
-__pkgversion__ = ""
+__pkgversion__ = "(local)"
 __environment__ = "stable"
+__uploadsentry__ = "true"
